==> bonita-project-report-model-0.1.1-sources.jar: org/bonitasoft/plugin/analyze/report/model/Artifact.java <==
/**
 * Copyright (C) 2021 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2.0 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package org.bonitasoft.plugin.analyze.report.model;

import lombok.Data;

@Data
public class Artifact {
    
    private String groupId;
    private String artifactId;
    private String version;
    private String classifier;
    private String file;
    
    public static Artifact create(String groupId, String artifactId, String version, String classifier, String file) {
        Artifact artifact = new Artifact();
        artifact.setGroupId(groupId);
        artifact.setArtifactId(artifactId);
        artifact.setVersion(version);
        artifact.setClassifier(classifier);
        artifact.setFile(file);
        return artifact;
    }
    
    @Override
    public String toString() {
        return String.format("%s:%s:%s", groupId, artifactId, version);
    }
    
}

==> bonita-project-report-model-1.0.1-sources.jar: org/bonitasoft/plugin/analyze/report/model/Artifact.java <==
/** 
 * Copyright (C) 2021 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2.0 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package org.bonitasoft.plugin.analyze.report.model;

import lombok.Data;

@Data
public class Artifact {

    private String groupId;
    private String artifactId;
    private String version;
    private String classifier;
    private String file;

    public static Artifact create(String groupId, String artifactId, String version, String classifier, String file) {
        Artifact artifact = new Artifact();
        artifact.setGroupId(groupId);
        artifact.setArtifactId(artifactId);
        artifact.setVersion(version);
        artifact.setClassifier(classifier);
        artifact.setFile(file);
        return artifact;
    }

    @Override
    public String toString() {
        return classifier != null ? String.format("%s:%s:%s:%s", groupId, artifactId, version, classifier)
                : String.format("%s:%s:%s", groupId, artifactId, version);
    }

}
